import requests
import logging
from json.decoder import JSONDecodeError

LOGGER = logging.getLogger(__name__)

class ElasticRestSupport():
    """ Class that provides support for retrieving Elasticsearch documents over REST calls """

    def __init__(self, host):
        self.host = host

    def get(self, index, identifier):
        """
        Get the source of an Elasticsearch document by the identifier
        :param index: Elasticsearch index
        :type index: str
        :param identifier: document identifier
        :type identifier: str
        :rtype: dict
        """
        try:
            response = requests.get(f"http://{self.host}:9200/{index}/_source/{identifier}", timeout=30)
            if response.status_code == requests.codes.ok:
                return response.json()
            elif response.status_code == requests.codes.not_found:
                LOGGER.error(f"Product with identifier {identifier} was not found in Elasticsearch")
        except requests.exceptions.RequestException as e:
            LOGGER.error("Error while sending request to retrieve product metadata from Elasticsearch")
            raise e
        except JSONDecodeError as e:
            LOGGER.error("Could not decode Elasticsearch response to JSON")
            raise e

        raise Exception("Failed to get product metadata from Elasticsearch")
